@@ -42,13 +42,21 @@ dbus-send --session --dest=org.cairodock.CairoDock /org/cairodock/CairoDock org.
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-bindings.h>
 
+#ifdef __FreeBSD__
+#include <kvm.h>
+#include <sys/param.h>
+#include <sys/sysctl.h>
+#include <sys/user.h>
+#include <limits.h>
+#endif
+
 #include "interface-main-methods.h"
 #include "dbus-main-spec.h"
 #include "interface-applet-object.h"
 #include "interface-applet-signals.h"
 #include "applet-dbus.h"
 
-#define DISTANT_DIR "3.1.0"
+#define DISTANT_DIR "3.2.0"
 #define GETTEXT_NAME_EXTRAS "cairo-dock-plugins-extra"
 #define LOCALE_DIR_NAME "locale"
 
@@ -122,7 +130,7 @@ static gboolean _cd_dbus_register_new_module (const gchar *cModuleName, const gc
 	}
 	else  // on enregistre ce nouveau module.
 	{
-		pModule = g_new0 (CairoDockModule, 1);
+		pModule = gldi_object_new (CairoDockModule, &myModulesMgr);
 		CairoDockVisitCard *pVisitCard = g_new0 (CairoDockVisitCard, 1);
 		pModule->pVisitCard = pVisitCard;
 		pVisitCard->cModuleName = g_strdup (cModuleName);
@@ -139,7 +147,7 @@ static gboolean _cd_dbus_register_new_module (const gchar *cModuleName, const gc
 		pVisitCard->iCategory = iCategory;
 		if (cIconName != NULL)
 			pVisitCard->cIconFilePath = g_strdup (cIconName);  // take the filename as it is, the path will be searched when needed only.
-		if (pVisitCard->cIconFilePath == NULL)
+		else
 			pVisitCard->cIconFilePath = (cShareDataDir ? g_strdup_printf ("%s/icon", cShareDataDir) : NULL);
 		pVisitCard->iSizeOfConfig = 4;  // au cas ou ...
 		pVisitCard->iSizeOfData = 4;  // au cas ou ...
@@ -324,7 +332,7 @@ static gboolean _apply_package_update (gchar *cModuleName)
 		pUpdateTask = t->data;
 		if (pUpdateTask->pSharedMemory && strcmp (pUpdateTask->pSharedMemory, cModuleName) == 0)
 		{
-			myData.pUpdateTasksList = g_list_remove_link (myData.pUpdateTasksList, t);  /// g_list_delete_link ?...
+			myData.pUpdateTasksList = g_list_delete_link (myData.pUpdateTasksList, t);
 			cairo_dock_discard_task (pUpdateTask);
 			break;
 		}
@@ -364,9 +372,46 @@ static void _on_got_list (GHashTable *pPackagesTable, gpointer data)
   ///////////////
  /// SERVICE ///
 ///////////////
-
 void cd_dbus_clean_up_processes (gboolean bAll)
 {
+	#ifdef __FreeBSD__   // thanks to Max Power for the BSD port
+	kvm_t *kd; //pointer for KVM library
+	char errbuf[_POSIX2_LINE_MAX]; //error message
+	int nentries; //number of processes
+	int p; //current process
+	struct kinfo_proc *kp;
+	kd = kvm_openfiles (NULL,"/dev/null",NULL,O_RDONLY,errbuf);
+	if(kd == 0)
+	{
+		cd_warning ("Dbus : %s",errbuf);
+		return;
+	}
+	kp = kvm_getprocs(kd,KERN_PROC_PROC,0,&nentries);
+	for(p=0; p<nentries;p++)
+	{
+		//SEARCHING...
+		char** pidargv = kvm_getargv(kd,&kp[p],0);
+		if(pidargv==NULL)
+			continue;  // not able to get args
+		int pidargc;
+		for(pidargc=0;pidargv[pidargc];pidargc++);  // get the number or args
+		if(pidargc<3) //not enough parameters
+			continue;
+		if(strcmp (pidargv[pidargc-2], myData.cProgName) != 0)  // not our program name.
+			continue;
+		if(atoi (pidargv[pidargc-1]) == 0)  // last arg is not a number
+			continue;
+		
+		//..SEEK...
+		if (bAll || kp[p].ki_ppid==1) // old process, if parent exprired ppid is set to 1
+		{
+			//...AND DESTROY
+			cd_message ("this applet (%s %d) is linked to an old gldi process (%d), kill it.", kp[p].ki_comm, kp[p].ki_pid, kp[p].ki_ppid);
+			kill (kp[p].ki_pid, SIGKILL); // SIGTERM sometimes lets the process alive.
+		}
+	}
+	kvm_close(kd);
+	#else
 	static gchar cFilePathBuffer[23+1];  // /proc/12345/cmdline + 4octets de marge.
 	static gchar cContent[512+1];
 	
@@ -428,12 +473,12 @@ void cd_dbus_clean_up_processes (gboolean bAll)
 		}
 	}
 	g_dir_close (dir);
+	#endif
 }
 
 void cd_dbus_launch_service (void)
 {
 	g_return_if_fail (myData.pMainObject == NULL);
-	g_type_init();
 	cd_message ("dbus : launching service...");
 	
 	//\____________ define the base path on the bus. So each program built on gldi has its own path on the gldi bus, and will place its applets under its own path.
@@ -509,8 +554,12 @@ void cd_dbus_launch_service (void)
 	}
 	
 	//\____________ Start the bridge to Unity Launcher API.
+	/* launch it asap, because if another Unity claims the bus before us,
+	 * the messages will be emitted on the bus, and we might miss them.
+	 */
 	#ifdef DBUSMENU_GTK_FOUND // need SetMenu => DBusMenu
-	cairo_dock_launch_command (CD_PLUGINS_DIR"/cairo-dock-unity-bridge");  // launch it asap, because if another Unity claims the bus before us, the messages will be emited on the bus, and we might miss them.
+	if (myConfig.bLaunchLauncherAPIDaemon)
+		cairo_dock_launch_command (CD_PLUGINS_DIR"/cairo-dock-launcher-API-daemon");
 	#endif
 }
 
