@@ -29,73 +29,172 @@
 #include "applet-disk-usage.h"
 #include "applet-rame.h"
 
-gchar* ltrim( gchar* str, const gchar* t )  // Couper tout depuis la gauche
-{
-	char* curStr = NULL;
 
-	char look[ 256 ] = { 1, 0 };
+void rtrim( gchar* str, const gchar* t )  // Couper tout depuis la droite
+{
+	/* gchar* curEnd = str, *end = str;
+	gchar look[ 256 ] = { 1, 0 };
 	while( *t )
 		look[ (unsigned char)*t++ ] = 1;
-
-	curStr = str;
-	while( *curStr && look[ *curStr ] )
-		++curStr;
-	strcpy( str, curStr );
-	
-	return str; 
-} 
-
-gchar* rtrim( gchar* str, const gchar* t )  // Couper tout depuis la droite
-{
-	char* curEnd = str, *end = str;
-
-	char look[ 256 ] = { 1, 0 };
-	while( *t )
-		look[ (unsigned char)*t++ ] = 1;
-
 	while( *end )
 	{
 		if ( !look[ *end ] )
 			curEnd = end + 1;
 		++end;
 	}
-	*curEnd = '\0';
+	*curEnd = '\0';*/
+	gint iStrLength = strlen (str);
+	gint iTLength = strlen (t);
+	if (iStrLength < iTLength)
+		return;
 
-	return str;
+	gchar *cPosition = str + iStrLength - iTLength;
+	if (g_strcmp0 (cPosition, t) == 0)
+		cPosition[0] = '\0';
 }
 
+void ltrim( gchar* str, const gchar* t )  // Couper tout depuis la gauche
+{
+	g_strreverse (str);
+	gchar* cSearch = g_strdup (t);
+	g_strreverse (cSearch);
+	rtrim( str, cSearch);
+	g_strreverse (str);	
+	g_free (cSearch);
+} 
 
+/*
 gchar *g_str_replace (const gchar *cString, const gchar *cWord, const gchar *cReplace)
 {
+	gchar *cPart1;
+	gchar *cPart2;
+	gchar *cWordTemp;
 	if (g_strstr_len (cString, -1, cWord) != NULL) // On remplace
 	{
-		gchar *cFinalString = g_strdup_printf("%s", cString);
+		gchar *cFinalString = g_strdup (cString);
 		while (g_strstr_len (cFinalString, -1, cWord) != NULL)
 		{
-			gchar *cPart1 = g_strdup_printf("%s", cFinalString);
-			gchar *cWordTemp = g_strdup_printf("%s", cWord);
+			cPart1 = g_strdup (cFinalString);
+			cWordTemp = g_strdup (cWord);
 			g_strreverse (cPart1);
 			g_strreverse (cWordTemp);
 			cPart1 = strstr(cPart1, cWordTemp) ;
 			ltrim( cPart1, cWordTemp );
 			g_strreverse (cPart1);
-			gchar *cPart2 = g_strdup_printf("%s", cFinalString);
+			cPart2 = g_strdup (cFinalString);
 			
 			while (g_strstr_len (cPart2, -1, cWord) != NULL)
 			{
-				cPart2 = strstr(cPart2, cWord);
+				cPart2 = strstr(cPart2, cWord);				
 				ltrim( cPart2, cWord );
 			}
 			// On colle le texte au milieu
 			cFinalString = g_strdup_printf ("%s%s%s", cPart1,  g_strdup_printf("%s",cReplace), cPart2);
 			
 		}
-		return g_strdup_printf("%s", cFinalString);	
+		return g_strdup (cFinalString);
+		g_free (cFinalString);
 	}
 	else
-		return g_strdup_printf("%s",cString); // On retourne la phrase d'origine	
+		return g_strdup_printf("%s",cString); // Remplacement non trouvé -> On retourne la phrase d'origine
+	g_free (cPart1);
+	g_free (cPart2);
+	g_free (cWordTemp);
+}*/
+
+gchar *g_str_replace (gchar *cString, const gchar cWord, const gchar cReplace)
+{
+	if (! cString)
+		return NULL;
+
+	for (int i = 0; cString[i] != '\0'; i++)
+	{
+		if (cString[i] == cWord)
+			cString[i] = cReplace;
+	}
+	return cString;
 }
 
+void cd_doncky_get_color_from_xml (gchar *cNodeContent, double *fColor)
+{
+	int iText1, iText2, iText3, iText4;
+	sscanf (cNodeContent, "%d;%d;%d;%d", &iText1, &iText2, &iText3, &iText4);
+	
+	// On récupère le 1er champ -> red
+	fColor[0] = iText1 / 255;
+	// On récupère le 2ème champ -> = green
+	fColor[1] = iText2 / 255;
+	// On récupère le 3ème champ -> = blue
+	fColor[2] = iText3 / 255;
+	// On récupère le dernier champ -> alpha
+	fColor[3] = iText4 / 255;
+}
+
+void cd_doncky_export_color_to_conf (double *fColor, const gchar *cGroupName, const gchar *cParam, CairoDockModuleInstance *myApplet)
+{
+	gchar *cStringInConfig = NULL;
+	cStringInConfig = g_strdup_printf ("%f;%f;%f;%f;", fColor[0], fColor[1], fColor[2], fColor[3]);
+	g_str_replace (cStringInConfig, ',', '.');
+	cd_debug ("DONCKY-debug : %s=%s", cParam, cStringInConfig); 
+
+	cairo_dock_update_conf_file (CD_APPLET_MY_CONF_FILE, G_TYPE_STRING, cGroupName, cParam, cStringInConfig, G_TYPE_INVALID);  // On l'ecrit dans le fichier de config
+	g_free (cStringInConfig);
+}
+
+/*
+gchar *g_str_position (const gchar *cString, const int iPosition, const char cSeparator)
+{
+	gchar *strSeparator = g_strdup_printf("%c", cSeparator);
+	
+	if ((g_strstr_len (cString, -1, strSeparator) != NULL) && (iPosition > 0)) // Separator trouvé -> On coupe
+	{
+		gchar *cFinalString = g_strdup (cString);
+		
+		if (iPosition == 1)
+		{			
+			g_strreverse (cFinalString);
+			cFinalString = strrchr(cFinalString, cSeparator);
+			ltrim( cFinalString, strSeparator);
+			g_strreverse (cFinalString);
+		}
+		else
+		{
+			int i = 1;
+			do
+			{
+				if (g_strstr_len (cFinalString, -1, strSeparator) == NULL) // Il n'y a plus de séparateur -> Mauvais champ spécifié
+				{
+					cd_debug ("DONCKY-debug :  /!\\ Missing values detected. Search for the string '%s' to fix it.", cString);
+					// On retourne 0 pour le champ non trouvé :
+					cFinalString = g_strdup_printf("0");
+					i = iPosition;
+				}
+				else
+				{
+					cFinalString = strchr(cFinalString, cSeparator);
+					ltrim( cFinalString, strSeparator);
+					i++;
+				}
+			}
+			while (i != iPosition);
+			
+			if ((g_strstr_len (cFinalString, -1, strSeparator) != NULL) && (iPosition > 0)) // Il reste des séparateurs -> On coupe les derniers champs
+			{
+				g_strreverse (cFinalString);
+				cFinalString = strrchr(cFinalString, cSeparator);
+				ltrim( cFinalString, strSeparator);
+				g_strreverse (cFinalString);
+			}
+		}
+		return g_strdup (cFinalString);
+		g_free (cFinalString);
+		g_free (strSeparator);
+	
+	}
+	else
+		return g_strdup_printf("%s",cString); // Pas de séparateur -> On retourne la phrase d'origine
+}*/
+
 
 double _Ko_to_Mo (CairoDockModuleInstance *myApplet , double fValueInKo)
 {
@@ -122,7 +221,7 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 		cd_sysmonitor_get_ram_data (myApplet);
 	if (myConfig.bShowNvidia)
 	{
-		if ((myData.iTimerCount % 3) == 0)  // la temperature ne varie pas tres vite et le script nvidia-settings est lours, on decide donc de ne mettre a jour qu'une fois sur 3.
+		if ((myData.iTimerCount % 3) == 0)  // la temperature ne varie pas tres vite et le script nvidia-settings est lourd, on decide donc de ne mettre a jour qu'une fois sur 3.
 			cd_sysmonitor_get_nvidia_data (myApplet);
 	}	
 	if (! myData.bInitialized)
@@ -131,7 +230,7 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 		myData.bInitialized = TRUE;
 	}
 	myData.iTimerCount ++;
-	
+	cd_debug ("=== Refresh");
 	
 	
 	// Autre :
@@ -142,8 +241,6 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 	{
 		pTextZone = it->data;
 		
-		
-		
 		if (!pTextZone->bImgDraw && pTextZone->cImgPath != NULL) // L'image n'a pas encore été chargée
 		{
 			
@@ -155,7 +252,8 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 				double fImgW=0, fImgH=0;
 				CairoDockLoadImageModifier iLoadingModifier = 0;  /// CAIRO_DOCK_FILL_SPACE
 				iLoadingModifier |= CAIRO_DOCK_KEEP_RATIO;
-				
+
+				cairo_surface_destroy (pTextZone->pImgSurface);
 				pTextZone->pImgSurface = cairo_dock_create_surface_from_image (pTextZone->cImgPath,
 					1.,
 					pTextZone->iImgSize, pTextZone->iImgSize,
@@ -167,7 +265,7 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 				pTextZone->iWidth = (int)fImgW;
 				pTextZone->iHeight = (int)fImgH;
 			}
-						
+			cairo_surface_destroy (pTextZone->pImgSurface);
 			pTextZone->pImgSurface = cairo_dock_create_surface_for_icon (pTextZone->cImgPath,
 					pTextZone->iWidth, pTextZone->iHeight);
 					
@@ -175,25 +273,19 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 		}
 		
 		
-		
-		
-				
 		if (pTextZone->iRefresh != 0)
 				pTextZone->iTimer++;
 		
-		
 		if (pTextZone->bRefresh)
 		{
+			g_free (pTextZone->cResult);
 			if (pTextZone->bIsBash) // C'est une commande bash !
 				pTextZone->cResult = cairo_dock_launch_command_sync (pTextZone->cCommand);
 			else if (pTextZone->bIsInternal)// C'est une commande interne !
 			{
-			
 				if (strcmp (pTextZone->cCommand, "cpuperc") == 0)
 				{
-					pTextZone->cResult = g_strdup_printf ("%.0f", myData.fCpuPercent);
-										
-					if (atof(pTextZone->cResult) < 10)
+					if (myData.fCpuPercent < 10)
 						pTextZone->cResult = g_strdup_printf ("%.1f", myData.fCpuPercent);
 					else
 						pTextZone->cResult = g_strdup_printf ("%.0f", myData.fCpuPercent);
@@ -201,11 +293,9 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 				
 				else if (strcmp (pTextZone->cCommand, "cpuperc2f") == 0) // Restreint à 2 chiffres : de 00 à 99 !
 				{
-					pTextZone->cResult = g_strdup_printf ("%.0f", myData.fCpuPercent);
-					
-					if (atof(pTextZone->cResult) < 10)
+					if (myData.fCpuPercent < 10)
 						pTextZone->cResult = g_strdup_printf ("0%.0f", myData.fCpuPercent);
-					else if (atof(pTextZone->cResult) == 100)
+					else if (myData.fCpuPercent == 100)
 						pTextZone->cResult = g_strdup_printf ("99");
 					else
 						pTextZone->cResult = g_strdup_printf ("%.0f", myData.fCpuPercent);
@@ -213,57 +303,45 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 					
 				else if (strcmp (pTextZone->cCommand, "memperc") == 0)
 				{
-					pTextZone->cResult = g_strdup_printf ("%.0f", myData.fRamPercent);
-					
-					if (atof(pTextZone->cResult) < 10)
+					if (myData.fRamPercent < 10)
 						pTextZone->cResult = g_strdup_printf ("0%.0f", myData.fRamPercent);
-					else if (atof(pTextZone->cResult) == 100)
-						pTextZone->cResult = g_strdup_printf ("99");						
+					else if (myData.fRamPercent == 100)
+						pTextZone->cResult = g_strdup  ("99");
 					else
 						pTextZone->cResult = g_strdup_printf ("%.0f", myData.fRamPercent);
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "memperc2f") == 0) // Restreint à 2 chiffres : de 00 à 99 !
 				{
-					pTextZone->cResult = g_strdup_printf ("%.0f", myData.fRamPercent);
-					
-					if (atof(pTextZone->cResult) < 10)
+					if (myData.fRamPercent < 10)
 						pTextZone->cResult = g_strdup_printf ("%.1f", myData.fRamPercent);
 					else
 						pTextZone->cResult = g_strdup_printf ("%.0f", myData.fRamPercent);
 				}
-	
 										
 				else if (strcmp (pTextZone->cCommand, "mem") == 0) // en Mo
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Mo(myApplet, myData.ramTotal /100. * myData.fRamPercent));
-					pTextZone->cResult = g_strdup_printf ("%.0f", atof(pTextZone->cResult));
+					pTextZone->cResult = g_strdup_printf ("%.0f", _Ko_to_Mo(myApplet, myData.ramTotal /100. * myData.fRamPercent));
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "memg") == 0) // Identique à mem mais en Go
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Go(myApplet, myData.ramTotal /100. * myData.fRamPercent));
-					pTextZone->cResult = g_strdup_printf ("%.2f", atof(pTextZone->cResult));
+					pTextZone->cResult = g_strdup_printf ("%.2f", _Ko_to_Go(myApplet, myData.ramTotal /100. * myData.fRamPercent));
 				}
 
 				else if (strcmp (pTextZone->cCommand, "memmax") == 0) // en Mo
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Mo(myApplet, myData.ramTotal));
-					pTextZone->cResult = g_strdup_printf ("%.0f", atof(pTextZone->cResult));
+					pTextZone->cResult = g_strdup_printf ("%.0f", _Ko_to_Mo(myApplet, myData.ramTotal));
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "memmaxg") == 0) // Identique à memmax mais en Go
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Go(myApplet, myData.ramTotal));
-					pTextZone->cResult = g_strdup_printf ("%.2f", atof(pTextZone->cResult));
+					pTextZone->cResult = g_strdup_printf ("%.2f", _Ko_to_Go(myApplet, myData.ramTotal));
 				}
-				
 								
 				else if (strcmp (pTextZone->cCommand, "swapperc") == 0)
 				{
-					pTextZone->cResult = g_strdup_printf ("%.0f", myData.fSwapPercent);
-					
-					if (atof(pTextZone->cResult) < 10)
+					if (myData.fSwapPercent < 10)
 						pTextZone->cResult = g_strdup_printf ("%.1f", myData.fSwapPercent);
 					else
 						pTextZone->cResult = g_strdup_printf ("%.0f", myData.fSwapPercent);				
@@ -271,48 +349,41 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 				
 				else if (strcmp (pTextZone->cCommand, "swapperc2f") == 0) // Restreint à 2 chiffres : de 00 à 99 !
 				{
-					pTextZone->cResult = g_strdup_printf ("%.0f", myData.fSwapPercent);
-					
-					if (atof(pTextZone->cResult) < 10)
+					if (myData.fSwapPercent < 10)
 						pTextZone->cResult = g_strdup_printf ("0%.0f", myData.fSwapPercent);
-					else if (atof(pTextZone->cResult) == 100)
-						pTextZone->cResult = g_strdup_printf ("99");
+					else if (myData.fSwapPercent == 100)
+						pTextZone->cResult = g_strdup ("99");
 					else
 						pTextZone->cResult = g_strdup_printf ("%.0f", myData.fSwapPercent);
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "swap") == 0) // en Mo
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Mo(myApplet, myData.swapUsed));
+					double fTmp = _Ko_to_Mo(myApplet, myData.swapUsed);
 					
-					if (atof(pTextZone->cResult) < 10)
-						pTextZone->cResult = g_strdup_printf ("%.2f", atof(pTextZone->cResult));
-					else if (atof(pTextZone->cResult) < 100)
-						pTextZone->cResult = g_strdup_printf ("%.1f", atof(pTextZone->cResult));
+					if (fTmp < 10)
+						pTextZone->cResult = g_strdup_printf ("%.2f", fTmp);
+					else if (fTmp < 100)
+						pTextZone->cResult = g_strdup_printf ("%.1f", fTmp);
 					else
-						pTextZone->cResult = g_strdup_printf ("%.0f", atof(pTextZone->cResult));
+						pTextZone->cResult = g_strdup_printf ("%.0f", fTmp);
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "swapg") == 0) // Identique à swap mais en Go
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Go(myApplet, myData.swapUsed));
-					pTextZone->cResult = g_strdup_printf ("%.2f", atof(pTextZone->cResult));
+					pTextZone->cResult = g_strdup_printf ("%.2f", _Ko_to_Go(myApplet, myData.swapUsed));
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "swapmax") == 0) // en Mo
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Mo(myApplet, myData.swapTotal));
-					pTextZone->cResult = g_strdup_printf ("%.0f", atof(pTextZone->cResult));
+					pTextZone->cResult = g_strdup_printf ("%.0f", _Ko_to_Mo(myApplet, myData.swapTotal));
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "swapmaxg") == 0) // Identique à swapmax mais en Go
 				{
-					pTextZone->cResult = g_strdup_printf ("%f", _Ko_to_Go(myApplet, myData.swapTotal));
-					pTextZone->cResult = g_strdup_printf ("%.2f", atof(pTextZone->cResult));
+					pTextZone->cResult = g_strdup_printf ("%.2f", _Ko_to_Go(myApplet, myData.swapTotal));
 				}
 				
-				
-				
 				else if (strcmp (pTextZone->cCommand, "nvtemp") == 0)
 				{
 					myConfig.bShowNvidia = TRUE;
@@ -323,14 +394,14 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 				{
 					myConfig.bShowNvidia = TRUE;
 					cd_sysmonitor_get_nvidia_info (myApplet);					
-					pTextZone->cResult = g_strdup_printf ("%s", myData.cGPUName);					
+					pTextZone->cResult = g_strdup (myData.cGPUName);					
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "nvdriver") == 0)
 				{
 					myConfig.bShowNvidia = TRUE;
 					cd_sysmonitor_get_nvidia_info (myApplet);					
-					pTextZone->cResult = g_strdup_printf ("%s", myData.cDriverVersion);					
+					pTextZone->cResult = g_strdup (myData.cDriverVersion);					
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "nvram") == 0)
@@ -340,153 +411,64 @@ void cd_launch_command (CairoDockModuleInstance *myApplet)
 					pTextZone->cResult = g_strdup_printf ("%i", myData.iVideoRam);					
 				}
 				
-				
-				
-				
 				else if (strcmp (pTextZone->cCommand, "uptime") == 0)
 				{
 					gchar *cUpTime = NULL, *cActivityTime = NULL;
 					cd_sysmonitor_get_uptime (&cUpTime, &cActivityTime);		
-					pTextZone->cResult = g_strdup_printf ("%s", cUpTime);			
+					pTextZone->cResult = cUpTime;
+					g_free (cActivityTime);
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "fs_size") == 0)
 				{
 					if (strcmp (pTextZone->cMountPoint, "") != 0)
-						pTextZone->cResult = g_strdup_printf ("%s", cd_doncky_get_disk_info (pTextZone->cMountPoint, 0));
+						pTextZone->cResult = cd_doncky_get_disk_info (pTextZone->cMountPoint, 0);
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "fs_free") == 0)
-					pTextZone->cResult = g_strdup_printf ("%s", cd_doncky_get_disk_info (pTextZone->cMountPoint, 1));
+					pTextZone->cResult = cd_doncky_get_disk_info (pTextZone->cMountPoint, 1);
 					
 				else if (strcmp (pTextZone->cCommand, "fs_used") == 0)
-					pTextZone->cResult = g_strdup_printf ("%s", cd_doncky_get_disk_info (pTextZone->cMountPoint, 2));
+					pTextZone->cResult = cd_doncky_get_disk_info (pTextZone->cMountPoint, 2);
 				
 				else if (strcmp (pTextZone->cCommand, "fs_freeperc") == 0)
-					pTextZone->cResult = g_strdup_printf ("%s", cd_doncky_get_disk_info (pTextZone->cMountPoint, 3));
+					pTextZone->cResult = cd_doncky_get_disk_info (pTextZone->cMountPoint, 3);
 				
 				else if (strcmp (pTextZone->cCommand, "fs_usedperc") == 0)
 				{
-					if (strcmp (pTextZone->cMountPoint, "") == 0 || pTextZone->cMountPoint == NULL)
-						pTextZone->cMountPoint = g_strdup_printf ("/");	
-					pTextZone->cResult = g_strdup_printf ("%s", cd_doncky_get_disk_info (pTextZone->cMountPoint, 4));
+					if (pTextZone->cMountPoint == NULL || pTextZone->cMountPoint == '\0')
+						pTextZone->cMountPoint = g_strdup ("/");	
+					pTextZone->cResult = cd_doncky_get_disk_info (pTextZone->cMountPoint, 4);
 				}
 				
 				else if (strcmp (pTextZone->cCommand, "fs_type") == 0)
-					pTextZone->cResult = g_strdup_printf ("%s", cd_doncky_get_disk_info (pTextZone->cMountPoint, 5));
+					pTextZone->cResult = cd_doncky_get_disk_info (pTextZone->cMountPoint, 5);
 				
 				else if (strcmp (pTextZone->cCommand, "fs_device") == 0)
-					pTextZone->cResult = g_strdup_printf ("%s", cd_doncky_get_disk_info (pTextZone->cMountPoint, 6));				
-				
-			}			
+					pTextZone->cResult = cd_doncky_get_disk_info (pTextZone->cMountPoint, 6);
+			}
+			// cd_debug ("===== %s (%d %d) => %s", pTextZone->cCommand, pTextZone->bIsBash, pTextZone->bIsInternal, pTextZone->cResult);
 		}
 	}	
 }
 
 gboolean cd_retrieve_command_result (CairoDockModuleInstance *myApplet)
 {
-	
-	// SYSTEM-MONITOR
-	static double s_fValues[CD_SYSMONITOR_NB_MAX_VALUES];
-	CD_APPLET_ENTER;
-	
-	if ( ! myData.bAcquisitionOK)
-	{
-		cd_warning ("One or more datas couldn't be retrieved");	
-		memset (s_fValues, 0, sizeof (s_fValues));
-		CD_APPLET_RENDER_NEW_DATA_ON_MY_ICON (s_fValues);
-	}
-	else
-	{
-		if (! myData.bInitialized)
-		{
-			memset (s_fValues, 0, sizeof (s_fValues));
-			CD_APPLET_RENDER_NEW_DATA_ON_MY_ICON (s_fValues);
-		}
-		else
-		{
-			// Copier les donnes en memoire partagee...
-			
-			//~ if (myConfig.iInfoDisplay == CAIRO_DOCK_INFO_ON_ICON || (myDock && myConfig.iInfoDisplay == CAIRO_DOCK_INFO_ON_LABEL))  // on affiche les valeurs soit en info-rapide, soit sur l'etiquette en mode dock.
-			//~ {
-				//~ gboolean bOneLine = (myConfig.iInfoDisplay == CAIRO_DOCK_INFO_ON_LABEL);
-				//~ GString *sInfo = g_string_new ("");
-				//~ if (myConfig.bShowCpu)
-				//~ {
-					//~ g_string_printf (sInfo, (myData.fCpuPercent < 10 ? "%s%.1f%%%s" : "%s%.0f%%%s"),
-						//~ (myDesklet ? "CPU:" : ""),
-						//~ myData.fCpuPercent,
-						//~ (bOneLine ? " - " : "\n"));
-				//~ }
-				//~ if (myConfig.bShowRam)
-				//~ {
-					//~ g_string_append_printf (sInfo, (myData.fRamPercent < 10 ? "%s%.1f%%%s" : "%s%.0f%%%s"),
-						//~ (myDesklet ? "RAM:" : ""),
-						//~ myData.fRamPercent,
-						//~ (bOneLine ? " - " : "\n"));
-				//~ }
-				//~ if (myConfig.bShowSwap)
-				//~ {
-					//~ g_string_append_printf (sInfo, (myData.fSwapPercent < 10 ? "%s%.1f%%%s" : "%s%.0f%%%s"),
-						//~ (myDesklet ? "SWAP:" : ""),
-						//~ myData.fSwapPercent,
-						//~ (bOneLine ? " - " : "\n"));
-				//~ }
-				//~ if (myConfig.bShowNvidia)
-				//~ {
-					//~ g_string_append_printf (sInfo, "%s%dÂ°C%s",
-						//~ (myDesklet ? "GPU:" : ""),
-						//~ myData.iGPUTemp,
-						//~ (bOneLine ? " - " : "\n"));
-				//~ }
-				//~ sInfo->str[sInfo->len-(bOneLine?3:1)] = '\0';
-				//~ if (bOneLine)
-					//~ CD_APPLET_SET_NAME_FOR_MY_ICON (sInfo->str);
-				//~ else
-					//~ CD_APPLET_SET_QUICK_INFO_ON_MY_ICON (sInfo->str);
-				//~ g_string_free (sInfo, TRUE);
-			//~ }
-			
-			if (myData.bNeedsUpdate || myConfig.iDisplayType == CD_SYSMONITOR_GRAPH)
-			{
-				int i = 0;
-				if (myConfig.bShowCpu)
-				{
-					s_fValues[i++] = myData.fCpuPercent / 100.;
-				}
-				if (myConfig.bShowRam)
-				{
-					s_fValues[i++] = myData.fRamPercent / 100.;
-				}
-				if (myConfig.bShowSwap)
-					s_fValues[i++] = (myData.swapTotal ? ((double)myData.swapUsed) / myData.swapTotal : 0.);
-				if (myConfig.bShowNvidia)
-					s_fValues[i++] = myData.fGpuTempPercent / 100.;
-				
-				CD_APPLET_RENDER_NEW_DATA_ON_MY_ICON (s_fValues);
-			}
-		}
-	}
-	
-	
-	
-	// Autre :
-	
 	GList *it;
 	TextZone *pTextZone;
 	
-
 	for (it = myData.pTextZoneList; it != NULL; it = it->next)
 	{
 		pTextZone = it->data;
-			
+		
 		if (pTextZone->iRefresh != 0 || pTextZone->bRefresh)
 		{
 			if (pTextZone->bRefresh && pTextZone->cResult != NULL)
 			{
-				pTextZone->cText = g_strdup_printf ("%s",pTextZone->cResult);
+				g_free (pTextZone->cText);
+				pTextZone->cText = g_strdup (pTextZone->cResult);
 			}
-						    
+			
 			if (pTextZone->iRefresh != 0 && pTextZone->iTimer >= pTextZone->iRefresh)
 			{
 				pTextZone->bRefresh = TRUE;
@@ -494,21 +476,24 @@ gboolean cd_retrieve_command_result (CairoDockModuleInstance *myApplet)
 			}
 			else // Pas de refresh de spécifié
 			{
-				
-				if (pTextZone->cText == NULL || strcmp (pTextZone->cText, "") == 0) // La récupération s'est mal passé -> On relance !
+				if (pTextZone->cText == NULL || strcmp (pTextZone->cText, "Please wait...") == 0) // La récupération s'est mal passé -> On relance !
+				{
 					pTextZone->bRefresh = TRUE;
+					pTextZone->iTimer = 0; // On remet le timer à 0
+					
+					cd_debug ("DONCKY-debug : Error with this command =  %s (%d, %d, %s, %s)", pTextZone->cCommand, pTextZone->iRefresh, pTextZone->bRefresh, pTextZone->cText, pTextZone->cResult);
+				}	
 				else			
 					pTextZone->bRefresh = FALSE; // On a récupéré l'info -> On arrête là !
 			}
-		}	
+		}
 	}
 	cd_applet_update_my_icon (myApplet); // Quand tous les textes sont chargés, on peut dessiner
-	myData.pPeriodicRefreshTask = NULL;
-		
-	CD_APPLET_LEAVE (myData.bAcquisitionOK);
+	return TRUE;
 }
 
 
+
 void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, int iHeight)
 {
 	PangoLayout *pLayout = pango_cairo_create_layout (myDrawContext);
@@ -562,8 +547,6 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 		cairo_restore (myDrawContext);
 	}
 	
-	
-	
 	// ################################################################################################################################################################
 	// ############ DEBUT DU DESSIN DU TEXTE
 	// ################################################################################################################################################################
@@ -578,7 +561,6 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 	TextZone *pTextZone;
 	
 	GList *it1;
-	gboolean bFirstPass=TRUE;
 
 	double fCurrentLineWidth = 0; // Dimension de la ligne complète (= avec plusieurs zones de textes)
 	double fCurrentLineHeight = 0;
@@ -598,8 +580,8 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 		{
 			pTextZone = it->data;
 			
-			if (pTextZone->cFont == NULL || pTextZone->cFont =="") // Si aucune font -> on prend celle de la config
-				pTextZone->cFont = g_strdup_printf("%s", myConfig.cDefaultFont);			
+			if (pTextZone->cFont == NULL || pTextZone->cFont == '\0') // Si aucune font -> on prend celle de la config
+				pTextZone->cFont = g_strdup (myConfig.cDefaultFont);			
 						
 			if (pTextZone->cText != NULL && ! (pTextZone->bBar || pTextZone->bLimitedBar || pTextZone->bImgDraw))
 			{
@@ -637,53 +619,16 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 			it = it->next;
 		} while (it != NULL && ! pTextZone->bEndOfLine);
 		
-		
-		
+
 		
 		//\_______ boucle sur it de it1 jusqu'à retour chariot => DESSIN
 		it = it1;
 		do
 		{
-	
 			pTextZone = it->data;
-			
-			
-			
-			
-			
-			
-		
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
-			
 						
-			if (pTextZone->cFont == NULL || pTextZone->cFont =="") // Si aucune font -> on prend celle de la config
-				pTextZone->cFont = g_strdup_printf("%s", myConfig.cDefaultFont);
-			
+			if (pTextZone->cFont == NULL || pTextZone->cFont == '\0') // Si aucune font -> on prend celle de la config
+				pTextZone->cFont = g_strdup (myConfig.cDefaultFont);
 			
 			 // On calcule le décalage WIDTH nécéssaire pour respecter l'alignement sur la largeur souhaité
 			if (bFirstTextInLine)
@@ -706,7 +651,6 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 						myData.fCurrentX = iWidth - iMargin - myConfig.iTextMargin - pTextZone->iWidth - pTextZone->iFontSizeWidth;
 					else
 						myData.fCurrentX = iWidth - iMargin - myConfig.iTextMargin - fCurrentLineWidth - pTextZone->iFontSizeWidth;
-					
 				}
 				
 				if (pTextZone->bBar)
@@ -715,10 +659,16 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 			
 			
 			if (! bFirstTextInLine)
-				pTextZone->cAlignHeight = g_strdup_printf("%s", myData.cLastAlignHeight); // On récupère l'alignement de la ligne (=l'alignement du 1er élément)
+			{
+				g_free (pTextZone->cAlignHeight);
+				pTextZone->cAlignHeight = g_strdup (myData.cLastAlignHeight); // On récupère l'alignement de la ligne (=l'alignement du 1er élément)
+			}
 			else
-				myData.cLastAlignHeight = g_strdup_printf("%s", pTextZone->cAlignHeight); // On mémorise l'aligenement du 1er élément de la ligne
-				
+			{
+				g_free (myData.cLastAlignHeight);
+				myData.cLastAlignHeight = g_strdup (pTextZone->cAlignHeight); // On mémorise l'aligenement du 1er élément de la ligne
+			}
+			
 			// On calcule le décalage HEIGHT nécéssaire pour respecter l'alignement sur la hauteur souhaité		
 			if (strcmp (pTextZone->cAlignHeight, "middle") == 0)
 			{
@@ -758,7 +708,6 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 				pango_layout_set_text (pLayout, pTextZone->cText, -1);
 			else
 				pango_layout_set_text (pLayout,"", -1);
-			pango_layout_get_pixel_extents (pLayout, &ink, &log);
 			
 			
 			if (pTextZone->bBar || pTextZone->bLimitedBar) // On dessine la barre
@@ -779,7 +728,8 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 				{
 					if (i==0)
 					{
-						myData.cCurrentText = g_strdup_printf ("%s",pTextZone->cText); // Sinon, çà plante à la ligne d'en dessous
+						g_free (myData.cCurrentText);
+						myData.cCurrentText = g_strdup (pTextZone->cText); // Sinon, çà plante à la ligne d'en dessous
 						value = (int)((atof(myData.cCurrentText) / 100)*pTextZone->iWidth);						
 					}
 					else
@@ -937,14 +887,10 @@ void cd_applet_draw_my_desklet (CairoDockModuleInstance *myApplet, int iWidth, i
 
 void cd_applet_update_my_icon (CairoDockModuleInstance *myApplet)
 {
-	//~ if (myDesklet)
-	//~ {
-		// taille de la texture.
-		int iWidth, iHeight;
-		CD_APPLET_GET_MY_ICON_EXTENT (&iWidth, &iHeight);
-		
-		cd_applet_draw_my_desklet (myApplet, iWidth, iHeight);		
-		
-		CD_APPLET_REDRAW_MY_ICON;
-	//~ }
+	// taille de la texture.
+	int iWidth, iHeight;
+	CD_APPLET_GET_MY_ICON_EXTENT (&iWidth, &iHeight);	
+	cd_applet_draw_my_desklet (myApplet, iWidth, iHeight);
+	
+	CD_APPLET_REDRAW_MY_ICON;
 }
