@@ -49,14 +49,12 @@ CD_APPLET_INIT_BEGIN
 	
 	CD_APPLET_SET_DEFAULT_IMAGE_ON_MY_ICON_IF_NONE;  // set the default icon if none is specified in conf.
 	
-	if (myConfig.bShowRecent)
-	{
-		cd_menu_init_recent (myApplet);
-	}
-	myData.pMenu = create_main_menu (myApplet);
-	myData.iShowQuit = myConfig.iShowQuit;
-	myData.iPanelDefaultMenuIconSize = cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR); // 24 by default
+	myData.iPanelDefaultMenuIconSize = cairo_dock_search_icon_size (GTK_ICON_SIZE_LARGE_TOOLBAR);
 	
+	cd_menu_start ();
+	
+	myData.iShowQuit = myConfig.iShowQuit;
+
 	CD_APPLET_REGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_MIDDLE_CLICK_EVENT;
 	CD_APPLET_REGISTER_FOR_BUILD_MENU_EVENT;
@@ -79,7 +77,7 @@ CD_APPLET_STOP_BEGIN
 	CD_APPLET_UNREGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_MIDDLE_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
-	
+
 	// keyboard events
 	cd_keybinder_unbind (myData.cKeyBinding);
 	cd_keybinder_unbind (myData.cKeyBindingQuickLaunch);
@@ -102,20 +100,17 @@ CD_APPLET_RELOAD_BEGIN
 		cd_keybinder_rebind (myData.cKeyBindingQuickLaunch, myConfig.cQuickLaunchShortkey, NULL);
 		
 		// on reset ce qu'il faut.
-		cd_menu_reset_recent (myApplet);  // le fitre peut avoir change.
 		if (myData.pMenu != NULL &&
 			(myConfig.iShowQuit != myData.iShowQuit))
 		{
-			gtk_widget_destroy (myData.pMenu);  // will destroy the 'recent items' sub-menu
-			myData.pMenu = NULL;
-			myData.pRecentMenuItem = NULL;
+			cd_menu_stop ();  // this is not very optimized but well...
 			myData.iShowQuit = myConfig.iShowQuit;
 		}
 		
 		// on reconstruit ce qu'il faut.
 		if (myData.pMenu == NULL)
 		{
-			myData.pMenu = create_main_menu (myApplet);
+			cd_menu_start ();
 		}
 		else  // menu deja existant, on rajoute/enleve les recents a la main.
 		{
@@ -129,15 +124,11 @@ CD_APPLET_RELOAD_BEGIN
 			}
 			else  // on veut les recent items.
 			{
-				cd_menu_init_recent (myApplet);
 				if (myData.pRecentMenuItem != NULL)  // ils existent deja.
 				{
-					GtkWidget *pRecentMenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (myData.pRecentMenuItem));
-					if (myData.pRecentFilter != NULL)
-						gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (myData.pRecentMenuItem), myData.pRecentFilter);
-					
-					if (myData.iNbRecentItems != myConfig.iNbRecentItems)
+					if (myData.iNbRecentItems != myConfig.iNbRecentItems)  // rebuild the recent sub-menu
 					{
+						GtkWidget *pRecentMenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (myData.pRecentMenuItem));
 						gtk_widget_destroy (pRecentMenu);
 						cd_menu_append_recent_to_menu (myData.pMenu, myApplet);
 					}
@@ -148,9 +139,5 @@ CD_APPLET_RELOAD_BEGIN
 				}
 			}
 		}
-	}
-	else if (myData.pMenu) // handle a change in the icon theme
-	{
-		reload_image_menu_items ();
-	}
+	}  // no need to do anything if the icons theme changes, because the gtk-images are loaded with a GIcon (idem for the Recent sub-menu)
 CD_APPLET_RELOAD_END
