@@ -23,28 +23,15 @@
 #include "applet-struct.h"
 #include "applet-recent.h"
 #include "applet-run-dialog.h"
+#include "applet-menu.h"
 #include "applet-notifications.h"
 
+static const gchar *s_cEditMenuCmd = NULL; // we need to check with 'which' only one time if alacarte or kmenuedit is available
 
-static void cd_menu_show_menu (void)
-{
-	if (myData.pMenu != NULL)
-	{
-		CD_APPLET_POPUP_MENU_ON_MY_ICON (myData.pMenu);
-	}
-}
 
 static void cd_menu_show_hide_quick_launch (void)
 {
-	if (myData.pQuickLaunchDialog == NULL)
-	{
-		myData.pQuickLaunchDialog = cd_menu_create_quick_launch_dialog (myApplet);
-		cairo_dock_dialog_reference (myData.pQuickLaunchDialog);
-	}
-	else
-	{
-		cairo_dock_toggle_dialog_visibility (myData.pQuickLaunchDialog);
-	}
+	cd_run_dialog_show_hide (myApplet);
 }
 
 //\___________ Define here the action to be taken when the user left-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons.
@@ -56,34 +43,57 @@ CD_APPLET_ON_CLICK_END
 //\___________ Define here the entries you want to add to the menu when the user right-clicks on your icon or on its subdock or your desklet. The icon and the container that were clicked are available through the macros CD_APPLET_CLICKED_ICON and CD_APPLET_CLICKED_CONTAINER. CD_APPLET_CLICKED_ICON may be NULL if the user clicked in the container but out of icons. The menu where you can add your entries is available throught the macro CD_APPLET_MY_MENU; you can add sub-menu to it if you want.
 static void _cd_menu_configure_menu (GtkMenuItem *menu_item, gpointer data)
 {
+	CD_APPLET_ENTER;
+	GError *error = NULL;
 	if (myConfig.cConfigureMenuCommand != NULL)
 	{
-		cairo_dock_launch_command (myConfig.cConfigureMenuCommand);
+		g_spawn_command_line_async (myConfig.cConfigureMenuCommand, &error);
 	}
-	else
+	else if (s_cEditMenuCmd != NULL)
 	{
-		if (g_iDesktopEnv == CAIRO_DOCK_GNOME || g_iDesktopEnv == CAIRO_DOCK_XFCE)  /// a confirmer pour XFCE ...
-			cairo_dock_launch_command ("alacarte");
-		else if (g_iDesktopEnv == CAIRO_DOCK_KDE)
-			cairo_dock_launch_command ("kmenuedit");
-		else
-			cd_warning ("Sorry, couldn't guess what to do to configure the menu");
+		g_spawn_command_line_async (s_cEditMenuCmd, &error);
 	}
+	
+	if (error != NULL)
+	{
+		cd_warning ("Attention : when trying to execute '%s' : %s",
+			myConfig.cConfigureMenuCommand ? myConfig.cConfigureMenuCommand : s_cEditMenuCmd,
+			error->message);
+		g_error_free (error);
+	}
+	CD_APPLET_LEAVE();
 }
+
+static gboolean _cd_check_edit_menu_cmd (const gchar *cWhich)
+{
+	gchar *cResult = cairo_dock_launch_command_sync (cWhich);  // Gnome (2 + 3(?)) + XFCE(?)
+	gboolean bResult = (cResult != NULL && *cResult == '/');
+	g_free (cResult);
+	return bResult;
+}
+
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-	// Main menu
 	gchar *cLabel = g_strdup_printf ("%s (%s)", D_("Quick launch"), D_("middle-click"));
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_EXECUTE, cd_menu_show_hide_quick_launch, CD_APPLET_MY_MENU);
 	g_free (cLabel);
 	CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
-	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Configure menu"), GTK_STOCK_PREFERENCES, _cd_menu_configure_menu, CD_APPLET_MY_MENU);
+
+	static gboolean bEditMenuCmdChecked = FALSE;
+	if (!myConfig.cConfigureMenuCommand && !bEditMenuCmdChecked)
+	{
+		bEditMenuCmdChecked = TRUE;
+		if (_cd_check_edit_menu_cmd ("which alacarte"))
+			s_cEditMenuCmd = "alacarte";
+		else if (_cd_check_edit_menu_cmd ("which kmenuedit"))
+			s_cEditMenuCmd = "kmenuedit";
+		else if (_cd_check_edit_menu_cmd ("which menulibre"))
+			s_cEditMenuCmd = "menulibre";
+	}
+	if (myConfig.cConfigureMenuCommand || s_cEditMenuCmd)
+		CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Configure menu"), GTK_STOCK_PREFERENCES, _cd_menu_configure_menu, CD_APPLET_MY_MENU);
 	
 	CD_APPLET_ADD_SEPARATOR_IN_MENU (CD_APPLET_MY_MENU);
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Clear recent"), GTK_STOCK_CLEAR, cd_menu_clear_recent, CD_APPLET_MY_MENU);
-	
-	// Sub-Menu
-	CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
 CD_APPLET_ON_BUILD_MENU_END
 
 
