@@ -30,9 +30,4 @@ void cd_menu_append_recent_to_menu (GtkWidget *top_menu, CairoDockModuleInstance
 void cd_menu_clear_recent (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet);
 
 
-void cd_menu_init_recent (CairoDockModuleInstance *myApplet);
-
-void cd_menu_reset_recent (CairoDockModuleInstance *myApplet);
-
-
 #endif
