@@ -217,9 +217,11 @@ void cd_indicator_set_icon (CDAppletIndicator *pIndicator, const gchar *cStatusI
 	if (cStatusIcon == NULL)
 		return;
 	
+	int iWidth, iHeight;
+	cairo_dock_get_icon_extent (myIcon, &iWidth, &iHeight);
 	const gchar *cIconName = cStatusIcon;
 	gchar *tmp_icon_name = NULL;
-	gchar *cIconPath = cairo_dock_search_icon_s_path (cIconName, MAX (myIcon->iImageWidth, myIcon->iImageHeight));  // on regarde si l'icone sera trouvee.
+	gchar *cIconPath = cairo_dock_search_icon_s_path (cIconName, MAX (iWidth, iHeight));  // on regarde si l'icone sera trouvee.
 	gchar *cIconPathFallback = NULL;
 	if (cIconPath == NULL)  // l'icone ne sera pas trouvee, on regarde si ce n'est pas une icone en carton d'Ubuntu.
 	{
@@ -228,7 +230,7 @@ void cd_indicator_set_icon (CDAppletIndicator *pIndicator, const gchar *cStatusI
 		{
 			tmp_icon_name = g_strndup (cIconName, str - cIconName);
 			cIconName = tmp_icon_name;
-			cIconPath = cairo_dock_search_icon_s_path (cIconName, MAX (myIcon->iImageWidth, myIcon->iImageHeight));
+			cIconPath = cairo_dock_search_icon_s_path (cIconName, MAX (iWidth, iHeight));
 		}
 	}
 	if (cIconPath == NULL)  // l'icone ne sera pas trouvee, on met une icone par defaut.
