@@ -121,9 +121,6 @@ static void _refresh (GtkMenuItem *menu_item, CairoDockModuleInstance *myApplet)
 	_update_feeds (myApplet);
 }
 CD_APPLET_ON_BUILD_MENU_BEGIN
-	GtkWidget *pSubMenu = CD_APPLET_CREATE_MY_SUB_MENU ();
-		CD_APPLET_ADD_ABOUT_IN_MENU (pSubMenu);
-		
 	CD_APPLET_ADD_IN_MENU_WITH_STOCK (D_("Paste a new RSS Url (drag and drop)"), GTK_STOCK_PASTE, _paste_new_url_to_conf, CD_APPLET_MY_MENU);	
 	
 	if (myConfig.cUrl != NULL) // On ajoute une entrée dans le menu SI il y a une url seulement
@@ -133,7 +130,6 @@ CD_APPLET_ON_BUILD_MENU_BEGIN
 		CD_APPLET_ADD_IN_MENU_WITH_STOCK (cLabel, GTK_STOCK_REFRESH, _refresh, CD_APPLET_MY_MENU);
 		g_free (cLabel);
 	}
-	
 CD_APPLET_ON_BUILD_MENU_END
 
 
