@@ -90,8 +90,8 @@ CD_APPLET_INIT_BEGIN
 		}
 	}
 	
-	myData.iDefaultWidth = myIcon->iImageWidth;
-	myData.iDefaultHeight = myIcon->iImageHeight;
+	myData.iDefaultWidth = myIcon->image.iWidth;
+	myData.iDefaultHeight = myIcon->image.iHeight;
 	cd_debug ("=== default size: %dx%d", myData.iDefaultWidth, myData.iDefaultHeight);
 	
 	cd_satus_notifier_launch_service ();
@@ -126,8 +126,8 @@ CD_APPLET_STOP_END
 
 //\___________ The reload occurs in 2 occasions : when the user changes the applet's config, and when the user reload the cairo-dock's config or modify the desklet's size. The macro CD_APPLET_MY_CONFIG_CHANGED can tell you this. myConfig has already been reloaded at this point if you're in the first case, myData is untouched. You also have the macro CD_APPLET_MY_CONTAINER_TYPE_CHANGED that can tell you if you switched from dock/desklet to desklet/dock mode.
 CD_APPLET_RELOAD_BEGIN
-	myData.iDefaultWidth = myIcon->iImageWidth;
-	myData.iDefaultHeight = myIcon->iImageHeight;
+	myData.iDefaultWidth = myIcon->image.iWidth;
+	myData.iDefaultHeight = myIcon->image.iHeight;
 	cd_debug ("=== default size <- %dx%d", myData.iDefaultWidth, myData.iDefaultHeight);
 	
 	if (CD_APPLET_MY_CONFIG_CHANGED)
@@ -181,10 +181,14 @@ CD_APPLET_RELOAD_BEGIN
 				myIcon->pSubDock = NULL;
 			}
 			cd_satus_notifier_reload_compact_mode ();
+			CD_APPLET_SET_STATIC_ICON;
 		}
 		else
 		{
+			// reload all icons
+			CD_APPLET_DELETE_MY_ICONS_LIST;
 			myData.iItemSize = 0;  // unvalidate the grid.
+			
 			cd_satus_notifier_load_icons_from_items ();
 			
 			if (myDock)
