@@ -56,30 +56,33 @@ static gboolean _unthreaded_task (CairoDockModuleInstance *myApplet)
 		memcpy (&fHighColor[3*i], myConfig.fHigholor, 3*sizeof (double));\
 		memcpy (&fLowColor[3*i], myConfig.fLowColor, 3*sizeof (double));\
 		i ++; }
-static void _set_data_renderer (CairoDockModuleInstance *myApplet, gboolean bReload)
+static void _set_data_renderer (CairoDockModuleInstance *myApplet)
 {
-	CairoDataRendererAttribute *pRenderAttr = NULL;  // les attributs generiques du data-renderer.
+	if (myConfig.iDisplayType == CD_SYSMONITOR_BAR)
+		return; /// TODO
+
+	CairoDataRendererAttribute *pRenderAttr = NULL;  // attributes for the global data-renderer.
+	CairoGaugeAttribute aGaugeAttr;  // gauge attributes.
+	CairoGraphAttribute aGraphAttr;  // graph attributes.
 	int iNbValues = myConfig.bShowCpu + myConfig.bShowRam + myConfig.bShowSwap + myConfig.bShowNvidia + myConfig.bShowCpuTemp + myConfig.bShowFanSpeed;
 	if (myConfig.iDisplayType == CD_SYSMONITOR_GAUGE)
 	{
-		CairoGaugeAttribute attr;  // les attributs de la jauge.
-		memset (&attr, 0, sizeof (CairoGaugeAttribute));
-		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
+		memset (&aGaugeAttr, 0, sizeof (CairoGaugeAttribute));
+		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&aGaugeAttr);
 		pRenderAttr->cModelName = "gauge";
 		pRenderAttr->iRotateTheme = myConfig.iRotateTheme;
-		attr.cThemePath = myConfig.cGThemePath;  
+		aGaugeAttr.cThemePath = myConfig.cGThemePath;
 	}
 	else if (myConfig.iDisplayType == CD_SYSMONITOR_GRAPH)
 	{
-		CairoGraphAttribute attr;  // les attributs du graphe.
-		memset (&attr, 0, sizeof (CairoGraphAttribute));
-		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&attr);
+		memset (&aGraphAttr, 0, sizeof (CairoGraphAttribute));
+		pRenderAttr = CAIRO_DATA_RENDERER_ATTRIBUTE (&aGraphAttr);
 		pRenderAttr->cModelName = "graph";
 		int w, h;
 		CD_APPLET_GET_MY_ICON_EXTENT (&w, &h);
 		pRenderAttr->iMemorySize = (w > 1 ? w : 32);  // fWidth peut etre <= 1 en mode desklet au chargement.
-		attr.iType = myConfig.iGraphType;
-		attr.bMixGraphs = myConfig.bMixGraph;
+		aGraphAttr.iType = myConfig.iGraphType;
+		aGraphAttr.bMixGraphs = myConfig.bMixGraph;
 		double fHighColor[CD_SYSMONITOR_NB_MAX_VALUES*3];
 		double fLowColor[CD_SYSMONITOR_NB_MAX_VALUES*3];
 		int i;
@@ -88,46 +91,35 @@ static void _set_data_renderer (CairoDockModuleInstance *myApplet, gboolean bRel
 			memcpy (&fHighColor[3*i], myConfig.fHigholor, 3*sizeof (double));
 			memcpy (&fLowColor[3*i], myConfig.fLowColor, 3*sizeof (double));
 		}
-		attr.fHighColor = fHighColor;
-		attr.fLowColor = fLowColor;
-		memcpy (attr.fBackGroundColor, myConfig.fBgColor, 4*sizeof (double));
+		aGraphAttr.fHighColor = fHighColor;
+		aGraphAttr.fLowColor = fLowColor;
+		memcpy (aGraphAttr.fBackGroundColor, myConfig.fBgColor, 4*sizeof (double));
 	}
-	else if (myConfig.iDisplayType == CD_SYSMONITOR_BAR)
+
+	pRenderAttr->iLatencyTime = myConfig.iCheckInterval * 1000 * myConfig.fSmoothFactor;
+	pRenderAttr->iNbValues = iNbValues;
+	if (myConfig.iInfoDisplay == CAIRO_DOCK_INFO_ON_ICON)
 	{
-		/// A FAIRE...
-	}
-	if (pRenderAttr != NULL)  // attributs generiques.
-	{
-		pRenderAttr->iLatencyTime = myConfig.iCheckInterval * 1000 * myConfig.fSmoothFactor;
-		pRenderAttr->iNbValues = iNbValues;
-		if (myConfig.iInfoDisplay == CAIRO_DOCK_INFO_ON_ICON)
-		{
-			pRenderAttr->bWriteValues = TRUE;
-			pRenderAttr->format_value = (CairoDataRendererFormatValueFunc)cd_sysmonitor_format_value;
-			pRenderAttr->pFormatData = myApplet;
-		}
-		//const gchar *c[] = {"/usr/share/icons/gnome/scalable/actions/gtk-about.svg", "/usr/share/icons/gnome/scalable/actions/gtk-help.svg", "", "", "", ""};
-		//pRenderAttr->cEmblems = c;
-		const gchar *labels[6] = {NULL, NULL, NULL, NULL, NULL, NULL};
-		int i = 0;
-		if (myConfig.bShowCpu)
-			labels[i++] = "CPU";
-		if (myConfig.bShowRam)
-			labels[i++] = "RAM";
-		if (myConfig.bShowSwap)
-			labels[i++] = "SWAP";
-		if (myConfig.bShowNvidia)
-			labels[i++] = "GPU";
-		if (myConfig.bShowCpuTemp)
-			labels[i++] = "TEMP";
-		if (myConfig.bShowFanSpeed)
-			labels[i++] = "FAN";
-		pRenderAttr->cLabels = (gchar **)labels;
-		if (! bReload)
-			CD_APPLET_ADD_DATA_RENDERER_ON_MY_ICON (pRenderAttr);
-		else
-			CD_APPLET_RELOAD_MY_DATA_RENDERER (pRenderAttr);
+		pRenderAttr->bWriteValues = TRUE;
+		pRenderAttr->format_value = (CairoDataRendererFormatValueFunc)cd_sysmonitor_format_value;
+		pRenderAttr->pFormatData = myApplet;
 	}
+	const gchar *labels[6] = {NULL, NULL, NULL, NULL, NULL, NULL};
+	int i = 0;
+	if (myConfig.bShowCpu)
+		labels[i++] = "CPU";
+	if (myConfig.bShowRam)
+		labels[i++] = "RAM";
+	if (myConfig.bShowSwap)
+		labels[i++] = "SWAP";
+	if (myConfig.bShowNvidia)
+		labels[i++] = "GPU";
+	if (myConfig.bShowCpuTemp)
+		labels[i++] = "TEMP";
+	if (myConfig.bShowFanSpeed)
+		labels[i++] = "FAN";
+	pRenderAttr->cLabels = (gchar **)labels;
+	CD_APPLET_ADD_DATA_RENDERER_ON_MY_ICON (pRenderAttr);
 }
 
 CD_APPLET_INIT_BEGIN
@@ -137,7 +129,7 @@ CD_APPLET_INIT_BEGIN
 	}
 	
 	// Initialisation du rendu.
-	_set_data_renderer (myApplet, FALSE);
+	_set_data_renderer (myApplet);
 	
 	// Initialisation de la tache periodique de mesure.
 	myData.pClock = g_timer_new ();
@@ -169,8 +161,9 @@ CD_APPLET_STOP_BEGIN
 	CD_APPLET_UNREGISTER_FOR_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_MIDDLE_CLICK_EVENT;
 	CD_APPLET_UNREGISTER_FOR_BUILD_MENU_EVENT;
-	
-	CD_APPLET_MANAGE_APPLICATION (NULL);
+
+	gchar *cNull = NULL;
+	CD_APPLET_MANAGE_APPLICATION (cNull);
 	
 #ifdef HAVE_SENSORS
 	cd_sysmonitor_clean_sensors ();
@@ -189,7 +182,7 @@ CD_APPLET_RELOAD_BEGIN
 			CD_APPLET_ALLOW_NO_CLICKABLE_DESKLET;
 		}
 		
-		_set_data_renderer (myApplet, TRUE);
+		_set_data_renderer (myApplet);
 		
 		CD_APPLET_SET_QUICK_INFO_ON_MY_ICON (NULL);
 		if (myConfig.iInfoDisplay != CAIRO_DOCK_INFO_ON_LABEL)
@@ -213,11 +206,11 @@ CD_APPLET_RELOAD_BEGIN
 		CD_APPLET_MANAGE_APPLICATION (myConfig.cSystemMonitorClass);
 	}
 	else {  // on redessine juste l'icone.
-		CD_APPLET_RELOAD_MY_DATA_RENDERER (NULL);
+		///CD_APPLET_RELOAD_MY_DATA_RENDERER (NULL);
 		if (myConfig.iDisplayType == CD_SYSMONITOR_GRAPH)
 			CD_APPLET_SET_MY_DATA_RENDERER_HISTORY_TO_MAX;
 		
-		CairoDockLabelDescription *pOldLabelDescription = myConfig.pTopTextDescription;
+		/**CairoDockLabelDescription *pOldLabelDescription = myConfig.pTopTextDescription;
 		myConfig.pTopTextDescription = cairo_dock_duplicate_label_description (&myDialogsParam.dialogTextDescription);
 		memcpy (myConfig.pTopTextDescription->fColorStart, pOldLabelDescription->fColorStart, 3*sizeof (double));
 		memcpy (myConfig.pTopTextDescription->fColorStop, pOldLabelDescription->fColorStop, 3*sizeof (double));
@@ -231,6 +224,6 @@ CD_APPLET_RELOAD_BEGIN
 			myData.fPrevSwapPercent = 0;
 			myData.fPrevGpuTempPercent = 0;
 			cd_sysmonitor_update_from_data (myApplet);
-		}
+		}*/
 	}
 CD_APPLET_RELOAD_END
