@@ -17,17 +17,22 @@
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
 #ifndef __CD_APPLET_STRUCT__
 #define  __CD_APPLET_STRUCT__
 
-#include <cairo-dock.h>
+#include <sys/types.h>
 #include <alsa/asoundlib.h>
-#ifdef SOUND_SERVICE_SUPPORT
+#define _STRUCT_TIMEVAL
+#include <cairo-dock.h>
+
+#ifdef INDICATOR_SOUNDMENU_WITH_IND3
+#include "indicator-applet3.h"
+#elif defined SOUND_SERVICE_SUPPORT // OLD
 #include "indicator-applet.h"
 #include "mute-widget.h"
 #endif
 
+// Info display types
 typedef enum {
 	VOLUME_NO_DISPLAY = 0,
 	VOLUME_ON_LABEL,
@@ -35,32 +40,38 @@ typedef enum {
 	VOLUME_NB_DISPLAYS
 	} VolumeTypeDisplay;
 
+// Icon display types
 typedef enum {
-	VOLUME_NO_EFFECT = 0,
-	VOLUME_EFFECT_ZOOM,
-	VOLUME_EFFECT_TRANSPARENCY,
+	VOLUME_EFFECT_NONE = 0,
 	VOLUME_EFFECT_BAR,
 	VOLUME_EFFECT_GAUGE,
 	VOLUME_NB_EFFECTS
 	} VolumeTypeEffect;
 
 struct _AppletConfig {
+	// alsa options
 	gchar *card_id;
 	gchar *cMixerElementName;
 	gchar *cMixerElementName2;
 	gchar *cShowAdvancedMixerCommand;
+	// display
 	VolumeTypeDisplay iVolumeDisplay;
 	VolumeTypeEffect iVolumeEffect;
 	gchar *cDefaultIcon;
 	gchar *cBrokenIcon;
 	gchar *cMuteIcon;
+	gchar *cGThemePath;
+	RendererRotateTheme iRotateTheme;
+	// accesibility
 	gchar *cShortcut;
 	gint iScrollVariation;
 	gboolean bHideScaleOnLeave;
-	gchar *cGThemePath;
-	RendererRotateTheme iRotateTheme;
+	#ifdef INDICATOR_SOUNDMENU_WITH_IND3
+	gchar *cIndicatorName;
+	#endif
 	} ;
 
+// Interface of a Sound Controler
 typedef struct {
 	int (*get_volume) (void);
 	void (*set_volume) (int iVolume);
@@ -73,7 +84,7 @@ typedef struct {
 struct _AppletData {
 	// generic interface
 	CDSoundCtl ctl;
-	// alsa
+	// alsa data
 	snd_mixer_t *mixer_handle;
 	gchar *mixer_card_name;
 	gchar *mixer_device_name;
@@ -85,12 +96,12 @@ struct _AppletData {
 	long iVolumeMin, iVolumeMax;  // volumes min et max en unites de la carte son.
 	guint iSidCheckVolume;
 	CairoDialog *pDialog;
-	cairo_surface_t *pSurface;
-	cairo_surface_t *pMuteSurface;
-	int iCurrentVolume;  // volume courant en %.
-	gboolean bIsMute;
-	// sound service
-	#ifdef SOUND_SERVICE_SUPPORT
+	int iCurrentVolume;  // current volume in [0-100]
+	// sound service data
+	#ifdef INDICATOR_SOUNDMENU_WITH_IND3
+	IndicatorObject *pIndicator;
+	IndicatorObjectEntry *pEntry;
+	#elif defined SOUND_SERVICE_SUPPORT // OLD
 	CDAppletIndicator *pIndicator;
 	GtkWidget* volume_widget;
 	GList *transport_widgets_list;
@@ -99,6 +110,8 @@ struct _AppletData {
 	gint iCurrentState;
 	#endif
 	// other
+	gboolean bIsMute;
+	gboolean bMuteImage;  // TRUE if the "mute" image is currently displayed
 	GtkWidget *pScale;
 	CairoKeyBinding *cKeyBinding;
 	} ;
