@@ -45,9 +45,11 @@ static void upload (const gchar *cFilePath, gchar *cDropboxDir, gboolean bAnonym
 	
 	// On lance la commande d'upload.
 	gchar *cCommand = NULL;
-	cCommand = g_strdup_printf ("curl --connect-timeout 5 --retry 2 --limit-rate %dk http://imageshack.us -F xml=yes -F tags=Cairo-Dock -F fileupload=@\"%s\" -o \"%s\"", iLimitRate, cFilePath, cLogFile);
+	cCommand = g_strdup_printf ("curl -L --connect-timeout 5 --retry 2 --limit-rate %dk http://imageshack.us -F xml=yes -F tags=Cairo-Dock -F fileupload=@\"%s\" -o \"%s\"", iLimitRate, cFilePath, cLogFile);
 	cd_debug ("%s", cCommand);
 	int r = system (cCommand);
+	if (r < 0)
+		cd_warning ("Not able to launch this command: %s", cCommand);
 	g_free (cCommand);
 	
 	// On récupère l'URL dans le log :
