@@ -19,9 +19,7 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include <GL/gl.h> 
-#include <gdk/x11/gdkglx.h>
-#include <gtk/gtkgl.h>
+#include <GL/gl.h>
 
 #include "applet-struct.h"
 #include "applet-notifications.h"
@@ -54,7 +52,6 @@ gboolean cd_drop_indicator_render (gpointer pUserData, CairoDock *pDock, cairo_t
 					(int) myData.dropIndicator.iWidth);
 			cairo_clip (pCairoContext);
 			
-			//cairo_move_to (pCairoContext, fX, 0);
 			if (pDock->container.bIsHorizontal)
 				cairo_translate (pCairoContext, fX, (pDock->container.bDirectionUp ? 0 : pDock->iActiveHeight));
 			else
@@ -102,7 +99,6 @@ gboolean cd_drop_indicator_render (gpointer pUserData, CairoDock *pDock, cairo_t
 				0.);
 		
 			cairo_mask (pCairoContext, pGradationPattern);
-			//cairo_paint (pCairoContext);
 			
 			cairo_pattern_destroy (pPattern);
 			cairo_pattern_destroy (pGradationPattern);
@@ -116,13 +112,23 @@ gboolean cd_drop_indicator_render (gpointer pUserData, CairoDock *pDock, cairo_t
 			{
 				cairo_save (pCairoContext);
 				if (pDock->container.bIsHorizontal)
+				{
 					cairo_translate (pCairoContext,
 						pIcon->fDrawX + 2./3*pIcon->fWidth*pIcon->fScale,
-						pIcon->fDrawY);
+						pIcon->fDrawY);  // top right corner
+					cairo_scale (pCairoContext,
+						pIcon->fWidth*pIcon->fScale/3 / myData.hoverIndicator.iWidth,
+						pIcon->fHeight*pIcon->fScale/3 / myData.hoverIndicator.iHeight);
+				}
 				else
+				{
 					cairo_translate (pCairoContext,
 						pIcon->fDrawY + 2./3*pIcon->fWidth*pIcon->fScale,
 						pIcon->fDrawX);
+					cairo_scale (pCairoContext,
+						pIcon->fHeight*pIcon->fScale/3 / myData.hoverIndicator.iWidth,
+						pIcon->fWidth*pIcon->fScale/3 / myData.hoverIndicator.iHeight);
+				}
 				cairo_set_source_surface (pCairoContext, myData.hoverIndicator.pSurface, 0., 0.);
 				cairo_paint_with_alpha (pCairoContext, pData->fAlphaHover);
 				cairo_restore (pCairoContext);
@@ -133,7 +139,7 @@ gboolean cd_drop_indicator_render (gpointer pUserData, CairoDock *pDock, cairo_t
 	{
 		if (pData->fAlpha > 0)
 		{
-			;double fX = pDock->container.iMouseX;
+			double fX = pDock->container.iMouseX;
 			double fY = (pDock->container.bDirectionUp ? pDock->iActiveHeight - myData.dropIndicator.iHeight : myData.dropIndicator.iHeight);
 			glPushMatrix();
 			glLoadIdentity();
@@ -224,7 +230,7 @@ gboolean cd_drop_indicator_render (gpointer pUserData, CairoDock *pDock, cairo_t
 			if (pIcon != NULL && ! CAIRO_DOCK_ICON_TYPE_IS_SEPARATOR (pIcon))
 			{
 				_cairo_dock_enable_texture ();
-				_cairo_dock_set_blend_over ();
+				_cairo_dock_set_blend_alpha ();
 				glPushMatrix ();
 				if (pDock->container.bIsHorizontal)
 					glTranslatef (pIcon->fDrawX + 5./6*pIcon->fWidth*pIcon->fScale,
@@ -324,7 +330,7 @@ gboolean cd_drop_indicator_update_dock (gpointer pUserData, CairoDock *pDock, gb
 	//g_print ("rect (%d;%d) (%dx%d)\n", rect.x, rect.y, rect.width, rect.height);
 	if (rect.width > 0 && rect.height > 0)
 	{
-		gdk_window_invalidate_rect (pDock->container.pWidget->window, &rect, FALSE);
+		cairo_dock_redraw_container_area (CAIRO_CONTAINER (pDock), &rect);
 	}
 	
 	if (pData && pData->fAlphaHover > 0)
@@ -356,7 +362,7 @@ void cd_drop_indicator_load_drop_indicator (gchar *cImage, int iWidth, int iHeig
 	}
 	if (myData.dropIndicator.iTexture != 0 && myData.iBilinearGradationTexture == 0)
 	{
-		myData.iBilinearGradationTexture = cairo_dock_load_texture_from_raw_data (gradationTex, 1, 32);
+		myData.iBilinearGradationTexture = cairo_dock_create_texture_from_raw_data (gradationTex, 1, 32);
 	}
 }
 
@@ -376,6 +382,7 @@ void cd_drop_indicator_load_hover_indicator (gchar *cImage, int iWidth, int iHei
 			iHeight,
 			CAIRO_DOCK_KEEP_RATIO);
 	}
+	cd_debug (" %p, %d, %d", myData.hoverIndicator.pSurface, myData.hoverIndicator.iTexture, g_bUseOpenGL);
 }
 
 void cd_drop_indicator_free_buffers (void)
