@@ -435,7 +435,6 @@ static Icon *_cd_get_icon_for_volume (GVolume *pVolume, GMount *pMount)
 			g_file_get_uri (pRootDir),
 			NULL,
 			0);
-		pNewIcon->iTrueType = CAIRO_DOCK_ICON_TYPE_FILE;
 		
 		g_object_unref (pRootDir);
 		g_object_unref (pIcon);
@@ -449,7 +448,6 @@ static Icon *_cd_get_icon_for_volume (GVolume *pVolume, GMount *pMount)
 			g_strdup (pNewIcon->cName),
 			NULL,
 			0);
-		pNewIcon->iTrueType = CAIRO_DOCK_ICON_TYPE_FILE;
 			
 		g_object_unref (pIcon);
 	}
@@ -630,7 +628,6 @@ GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iS
 			gchar *cName = NULL;
 			
 			icon = cairo_dock_create_dummy_launcher (NULL, NULL, NULL, NULL, 0);
-			icon->iTrueType = CAIRO_DOCK_ICON_TYPE_FILE;
 			icon->iGroup = iNewIconsType;
 			icon->cBaseURI = g_strconcat (*cFullURI, "/", cFileName, NULL);
 			cd_message ("+ %s (mime:%s)", icon->cBaseURI, cMimeType);
@@ -766,7 +763,6 @@ GList *vfs_backend_list_directory (const gchar *cBaseURI, CairoDockFMSortType iS
 			g_strdup ("/home"),
 			NULL,
 			iOrder++);
-		icon->iTrueType = CAIRO_DOCK_ICON_TYPE_FILE;
 		icon->iGroup = iNewIconsType;
 		icon->cBaseURI = g_strdup_printf ("file://%s", "/home");
 		icon->iVolumeID = 0;
@@ -1275,6 +1271,10 @@ void vfs_backend_empty_trash (void)
 
 gchar *vfs_backend_get_trash_path (const gchar *cNearURI, gchar **cFileInfoPath)
 {
+	if (cNearURI == NULL)
+		return g_strdup ("trash://"); // it seems it's supported: we can monitor trash://
+	// but it's possible that we are not able to open this URI with GVFS on KDE :-/ => need feedback
+
 	gchar *cPath = NULL;
 	/*GFile *pFile = g_file_new_for_uri ("trash://");
 	gchar *cPath = g_file_get_path (pFile);
