@@ -276,7 +276,7 @@ static gboolean cd_shortcuts_build_shortcuts_from_data (CDSharedMemory *pSharedM
 	{
 		case CD_DESKLET_SLIDE :
 		default :
-			cDeskletRendererName = "Slide";
+			cDeskletRendererName = "Viewport";
 		break ;
 		
 		case CD_DESKLET_TREE :
@@ -298,6 +298,12 @@ static gboolean cd_shortcuts_build_shortcuts_from_data (CDSharedMemory *pSharedM
 	
 	//\_______________________ On lance la tache de mesure des disques.
 	cd_shortcuts_launch_disk_periodic_task (myApplet);
+
+	if (myData.bShowMenuPending)
+	{
+		cairo_dock_notify_on_object (myContainer, NOTIFICATION_CLICK_ICON, myIcon, myDock, GDK_BUTTON1_MASK);
+		myData.bShowMenuPending = FALSE;
+	}
 	
 	cairo_dock_discard_task (myData.pTask);
 	myData.pTask = NULL;
@@ -333,6 +339,10 @@ void cd_shortcuts_start (CairoDockModuleInstance *myApplet)
 		(CairoDockUpdateSyncFunc) cd_shortcuts_build_shortcuts_from_data,
 		(GFreeFunc) _free_shared_memory,
 		pSharedMemory);
-	cairo_dock_launch_task (myData.pTask);
+
+	if (cairo_dock_is_loading ())
+		cairo_dock_launch_task_delayed (myData.pTask, 0); // 0 <=> g_idle
+	else
+		cairo_dock_launch_task (myData.pTask);
 }
 
