@@ -1,4 +1,4 @@
-/**
+	/**
 * This file is a part of the Cairo-Dock project
 *
 * Copyright : (C) see the 'copyright' file.
@@ -23,20 +23,13 @@
 
 #include "applet-transitions.h"
 
-#define _cd_slider_erase_surface(myApplet) do { \
-	cairo_set_source_rgba (myDrawContext, 0., 0., 0., 0.);\
-	cairo_set_operator (myDrawContext, CAIRO_OPERATOR_SOURCE);\
-	cairo_paint (myDrawContext);\
-	cairo_set_operator (myDrawContext, CAIRO_OPERATOR_OVER); } while (0)
+///#define _cd_slider_erase_surface(myApplet) cairo_dock_erase_cairo_context (myDrawContext)
 
-#define _cd_slider_add_background_to_slide(myApplet, fX, fY, alpha, slide) do { \
+/**#define _cd_slider_add_background_to_slide(myApplet, fX, fY, alpha, slide) do { \
 	if (myConfig.pBackgroundColor[3] != 0) {\
 	cairo_set_source_rgba (myDrawContext, myConfig.pBackgroundColor[0], myConfig.pBackgroundColor[1], myConfig.pBackgroundColor[2], alpha * myConfig.pBackgroundColor[3]);\
 	cairo_rectangle (myDrawContext, fX, fY, slide.fImgW, slide.fImgH);\
 	cairo_fill (myDrawContext); } } while (0)
-#define _cd_slider_add_background_to_current_slide(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide (myApplet, fX, fY, alpha, myData.slideArea)
-#define _cd_slider_add_background_to_prev_slide(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide (myApplet, fX, fY, alpha, myData.prevSlideArea)
-
 #define _cd_slider_add_background_to_slide_opengl(myApplet, fX, fY, alpha, slide) do { \
 	glColor4f (myConfig.pBackgroundColor[0], myConfig.pBackgroundColor[1], myConfig.pBackgroundColor[2], alpha * myConfig.pBackgroundColor[3]);\
 	glPolygonMode (GL_FRONT, GL_FILL);\
@@ -48,10 +41,70 @@
 		glVertex3f(fX + slide.fImgW/2, fY - slide.fImgH/2, 0.);\
 		glVertex3f(fX + slide.fImgW/2, fY + slide.fImgH/2, 0.);\
 		glVertex3f(fX - slide.fImgW/2, fY + slide.fImgH/2, 0.);\
-		glEnd(); } } while (0)
-#define _cd_slider_add_background_to_current_slide_opengl(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide_opengl (myApplet, fX, fY, alpha, myData.slideArea)
-#define _cd_slider_add_background_to_prev_slide_opengl(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide_opengl (myApplet, fX, fY, alpha, myData.prevSlideArea)
+		glEnd(); } } while (0)*/
 
+static void _cd_slider_add_background_to_slide (CairoDockModuleInstance *myApplet, double fX, double fY, double alpha, SliderImageArea *slide)
+{
+	if (myConfig.pBackgroundColor[3] != 0)
+	{
+		cairo_set_source_rgba (myDrawContext, myConfig.pBackgroundColor[0], myConfig.pBackgroundColor[1], myConfig.pBackgroundColor[2], alpha * myConfig.pBackgroundColor[3]);
+		if (myConfig.iBackgroundType == 2)
+		{
+			int iLineWidth = _get_frame_linewidth (myApplet);
+			double fRadius = MIN (5, .25*iLineWidth);
+			cairo_save (myDrawContext);
+			cairo_translate (myDrawContext, fX - .5*iLineWidth, fY);
+			cairo_dock_draw_rounded_rectangle (myDrawContext, fRadius, iLineWidth, slide->fImgW - (2*fRadius), slide->fImgH - iLineWidth);
+			cairo_set_line_width (myDrawContext, iLineWidth);
+			cairo_stroke (myDrawContext);
+			cairo_restore (myDrawContext);
+		}
+		else
+		{
+			cairo_rectangle (myDrawContext, fX, fY, slide->fImgW, slide->fImgH);
+			cairo_fill (myDrawContext);
+		}
+	}
+}
+#define _cd_slider_add_background_to_current_slide(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide (myApplet, fX, fY, alpha, &myData.slideArea)
+#define _cd_slider_add_background_to_prev_slide(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide (myApplet, fX, fY, alpha, &myData.prevSlideArea)
+
+static void _cd_slider_add_background_to_slide_opengl(CairoDockModuleInstance *myApplet, double fX, double fY, double alpha, SliderImageArea *slide)
+{
+	if (myConfig.pBackgroundColor[3] != 0)
+	{
+		glDisable (GL_TEXTURE_2D);
+		glColor4f (myConfig.pBackgroundColor[0], myConfig.pBackgroundColor[1], myConfig.pBackgroundColor[2], alpha * myConfig.pBackgroundColor[3]);
+		if (myConfig.iBackgroundType == 2)
+		{
+			int iLineWidth = _get_frame_linewidth (myApplet);
+			double fRadius = 1.33 * MIN (5, .25*iLineWidth);
+			glPushMatrix ();
+			glTranslatef (fX, fY, 0.);  // centre du rectangle.
+			glBlendFunc (GL_ONE, GL_ZERO);
+			cairo_dock_draw_rounded_rectangle_opengl (slide->fImgW - (2*fRadius) + iLineWidth, slide->fImgH + iLineWidth, fRadius, 0, NULL);  // we fill the rectangle, because the stroke function in opengl does not handle wide lines very well.
+			glPopMatrix ();
+			glPolygonMode (GL_FRONT, GL_FILL);
+		}
+		else
+		{
+			glPolygonMode (GL_FRONT, GL_FILL);
+			glEnable (GL_BLEND);
+			glBlendFunc (GL_ONE, GL_ZERO);
+			if (myConfig.pBackgroundColor[3] != 0)
+			{
+				glBegin(GL_QUADS);
+				glVertex3f(fX - slide->fImgW/2, fY - slide->fImgH/2, 0.);
+				glVertex3f(fX + slide->fImgW/2, fY - slide->fImgH/2, 0.);
+				glVertex3f(fX + slide->fImgW/2, fY + slide->fImgH/2, 0.);
+				glVertex3f(fX - slide->fImgW/2, fY + slide->fImgH/2, 0.);
+				glEnd();
+			}
+		}
+	}
+}
+#define _cd_slider_add_background_to_current_slide_opengl(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide_opengl (myApplet, fX, fY, alpha, &myData.slideArea)
+#define _cd_slider_add_background_to_prev_slide_opengl(myApplet, fX, fY, alpha) _cd_slider_add_background_to_slide_opengl (myApplet, fX, fY, alpha, &myData.prevSlideArea)
 
 void cd_slider_draw_default (CairoDockModuleInstance *myApplet)
 {
@@ -72,8 +125,9 @@ void cd_slider_draw_default (CairoDockModuleInstance *myApplet)
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO ();
 		//\______________________ On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		//\______________________ On empeche la transparence
 		_cd_slider_add_background_to_current_slide (myApplet, myData.slideArea.fImgX, myData.slideArea.fImgY, 1.);
@@ -81,6 +135,7 @@ void cd_slider_draw_default (CairoDockModuleInstance *myApplet)
 		//\______________________ On dessine la nouvelle surface.
 		cairo_set_source_surface (myDrawContext, myData.pCairoSurface, myData.slideArea.fImgX, myData.slideArea.fImgY);
 		cairo_paint (myDrawContext);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 }
 
@@ -119,8 +174,9 @@ gboolean cd_slider_fade (CairoDockModuleInstance *myApplet) {
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO (FALSE);
 		//On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		//Fond précédent.
 		if (myData.pPrevCairoSurface != NULL)
@@ -137,6 +193,7 @@ gboolean cd_slider_fade (CairoDockModuleInstance *myApplet) {
 		
 		cairo_set_source_surface (myDrawContext, myData.pCairoSurface, myData.slideArea.fImgX, myData.slideArea.fImgY);
 		cairo_paint_with_alpha (myDrawContext, myData.fAnimAlpha);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 	
 	return (myData.fAnimAlpha < .99);
@@ -157,6 +214,7 @@ gboolean cd_slider_blank_fade (CairoDockModuleInstance *myApplet) {
 		
 		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 		glEnable (GL_TEXTURE_2D);
+		glEnable (GL_BLEND);
 		glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_MODULATE);
 		
 		//Image
@@ -164,13 +222,13 @@ gboolean cd_slider_blank_fade (CairoDockModuleInstance *myApplet) {
 		cairo_dock_apply_texture_at_size (myData.iTexture, myData.slideArea.fImgW, myData.slideArea.fImgH);
 		
 		//Masque
+		glDisable (GL_TEXTURE_2D);
 		glColor4f (1., 1., 1., myData.fAnimAlpha);
 		glBegin(GL_QUADS);
-		glDisable (GL_TEXTURE_2D);
-		glVertex3f(-.5,  .5, 0.);
-		glVertex3f( .5,  .5, 0.);
-		glVertex3f( .5, -.5, 0.);
-		glVertex3f(-.5, -.5, 0.);
+		glVertex3f(-.5*myData.slideArea.fImgW,  .5*myData.slideArea.fImgH, 0.);
+		glVertex3f( .5*myData.slideArea.fImgW,  .5*myData.slideArea.fImgH, 0.);
+		glVertex3f( .5*myData.slideArea.fImgW, -.5*myData.slideArea.fImgH, 0.);
+		glVertex3f(-.5*myData.slideArea.fImgW, -.5*myData.slideArea.fImgH, 0.);
 		glEnd();
 		
 		glDisable (GL_BLEND);
@@ -178,8 +236,9 @@ gboolean cd_slider_blank_fade (CairoDockModuleInstance *myApplet) {
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO (FALSE);
 		//On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		//On empeche la transparence
 		_cd_slider_add_background_to_current_slide (myApplet, myData.slideArea.fImgX, myData.slideArea.fImgY, 1.);
@@ -192,6 +251,7 @@ gboolean cd_slider_blank_fade (CairoDockModuleInstance *myApplet) {
 		cairo_set_source_rgba (myDrawContext, 1., 1., 1., myData.fAnimAlpha);
 		cairo_rectangle(myDrawContext, 0., 0., myData.iSurfaceWidth, myData.iSurfaceHeight);
 		cairo_fill(myDrawContext);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 	
 	return (myData.fAnimAlpha > 0.01);
@@ -212,7 +272,7 @@ gboolean cd_slider_fade_in_out (CairoDockModuleInstance *myApplet) {
 	{
 		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN (FALSE);
 		
-		if (myData.iAnimCNT < myConfig.iNbAnimationStep)  // image precedente en train de disparaitre
+		if (myData.iAnimCNT < myConfig.iNbAnimationStep && myData.iPrevTexture != 0)  // image precedente en train de disparaitre
 		{
 			//On empeche la transparence
 			_cd_slider_add_background_to_prev_slide_opengl (myApplet, 0., 0., myData.fAnimAlpha);
@@ -243,8 +303,9 @@ gboolean cd_slider_fade_in_out (CairoDockModuleInstance *myApplet) {
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO (FALSE);
 		//On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		if (myData.iAnimCNT < myConfig.iNbAnimationStep)  // image precedente en train de disparaitre
 		{
@@ -261,6 +322,7 @@ gboolean cd_slider_fade_in_out (CairoDockModuleInstance *myApplet) {
 			cairo_set_source_surface (myDrawContext, myData.pCairoSurface, myData.slideArea.fImgX, myData.slideArea.fImgY);
 		}
 		cairo_paint_with_alpha (myDrawContext, myData.fAnimAlpha);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 	
 	return (myData.fAnimAlpha < .99);
@@ -308,8 +370,9 @@ gboolean cd_slider_side_kick (CairoDockModuleInstance *myApplet) {
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO (FALSE);
 		//On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		if (myData.sens == 1)  // image precedente qui part sur la gauche.
 		{
@@ -324,6 +387,7 @@ gboolean cd_slider_side_kick (CairoDockModuleInstance *myApplet) {
 			cairo_set_source_surface (myDrawContext, myData.pCairoSurface, myData.slideArea.fImgX + xcumul, myData.slideArea.fImgY);
 		}
 		cairo_paint (myDrawContext);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 	
 	return (myData.iAnimCNT > 0);
@@ -389,8 +453,9 @@ gboolean cd_slider_diaporama (CairoDockModuleInstance *myApplet) {
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO (FALSE);
 		//On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		//Image précédante
 		if (myData.pPrevCairoSurface != NULL)
@@ -406,6 +471,7 @@ gboolean cd_slider_diaporama (CairoDockModuleInstance *myApplet) {
 		
 		cairo_set_source_surface (myDrawContext, myData.pCairoSurface, myData.slideArea.fImgX + myData.iSurfaceWidth * (1 - myData.fAnimAlpha), myData.slideArea.fImgY);
 		cairo_paint(myDrawContext);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 	
 	return (myData.fAnimAlpha < .999);
@@ -421,7 +487,10 @@ gboolean cd_slider_grow_up (CairoDockModuleInstance *myApplet) {
 	{
 		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN (FALSE);
 		
-		_cd_slider_add_background_to_current_slide_opengl (myApplet, 0., 0., myData.fAnimAlpha);
+		glPushMatrix ();
+		glScalef (myData.fAnimAlpha, myData.fAnimAlpha, 1.);
+		_cd_slider_add_background_to_current_slide_opengl (myApplet, 0., 0., 1.);
+		glPopMatrix ();
 		
 		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 		glEnable (GL_TEXTURE_2D);
@@ -436,8 +505,9 @@ gboolean cd_slider_grow_up (CairoDockModuleInstance *myApplet) {
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO (FALSE);
 		//On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		//On met a l'échelle en recentrant.
 		cairo_save(myDrawContext);
@@ -450,6 +520,7 @@ gboolean cd_slider_grow_up (CairoDockModuleInstance *myApplet) {
 		
 		cairo_paint_with_alpha (myDrawContext, myData.fAnimAlpha);
 		cairo_restore(myDrawContext);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 	
 	return (myData.fAnimAlpha < .99);
@@ -465,7 +536,10 @@ gboolean cd_slider_shrink_down (CairoDockModuleInstance *myApplet) {
 	{
 		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN (FALSE);
 		
-		_cd_slider_add_background_to_current_slide_opengl (myApplet, 0., 0., myData.fAnimAlpha);
+		glPushMatrix ();
+		glScalef (myData.fAnimAlpha, myData.fAnimAlpha, 1.);
+		_cd_slider_add_background_to_current_slide_opengl (myApplet, 0., 0., 1.);
+		glPopMatrix ();
 		
 		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 		glEnable (GL_TEXTURE_2D);
@@ -480,8 +554,9 @@ gboolean cd_slider_shrink_down (CairoDockModuleInstance *myApplet) {
 	}
 	else
 	{
+		CD_APPLET_START_DRAWING_MY_ICON_OR_RETURN_CAIRO (FALSE);
 		//On efface le fond
-		_cd_slider_erase_surface (myApplet);
+		///_cd_slider_erase_surface (myApplet);
 		
 		//On met a l'échelle en recentrant.
 		cairo_save(myDrawContext);
@@ -494,6 +569,7 @@ gboolean cd_slider_shrink_down (CairoDockModuleInstance *myApplet) {
 		
 		cairo_paint_with_alpha (myDrawContext, myData.fAnimAlpha);
 		cairo_restore(myDrawContext);
+		CD_APPLET_FINISH_DRAWING_MY_ICON_CAIRO;
 	}
 	
 	return (myData.fAnimAlpha > 1.01);
