@@ -35,7 +35,7 @@ static void _terminal_copy (GtkMenuItem *menu_item, gpointer *data)
 {
 	GtkWidget *pWidget = data[0];
 	gchar *cReceivedData = data[1];
-	cd_message ("%s (%s)\n", __func__, cReceivedData);
+	cd_message ("%s (%s)", __func__, cReceivedData);
 	_terminal_write_command_with_data (pWidget, "", cReceivedData);
 }
 
@@ -43,28 +43,28 @@ static void _terminal_cd (GtkMenuItem *menu_item, gpointer *data)
 {
 	GtkWidget *pWidget = data[0];
 	gchar *cReceivedData = data[1];
-	cd_message ("%s (%s)\n", __func__, cReceivedData);
+	cd_message ("%s (%s)", __func__, cReceivedData);
 	_terminal_write_command_with_data (pWidget, "cd", cReceivedData);
 }
 static void _terminal_cp (GtkMenuItem *menu_item, gpointer *data)
 {
 	GtkWidget *pWidget = data[0];
 	gchar *cReceivedData = data[1];
-	cd_message ("%s (%s)\n", __func__, cReceivedData);
+	cd_message ("%s (%s)", __func__, cReceivedData);
 	_terminal_write_command_with_data (pWidget, "cp -r", cReceivedData);
 }
 static void _terminal_mv (GtkMenuItem *menu_item, gpointer *data)
 {
 	GtkWidget *pWidget = data[0];
 	gchar *cReceivedData = data[1];
-	cd_message ("%s (%s)\n", __func__, cReceivedData);
+	cd_message ("%s (%s)", __func__, cReceivedData);
 	_terminal_write_command_with_data (pWidget, "mv", cReceivedData);
 }
 static void _terminal_rm (GtkMenuItem *menu_item, gpointer *data)
 {
 	GtkWidget *pWidget = data[0];
 	gchar *cReceivedData = data[1];
-	cd_message ("%s (%s)\n", __func__, cReceivedData);
+	cd_message ("%s (%s)", __func__, cReceivedData);
 	_terminal_write_command_with_data (pWidget, "rm -r", cReceivedData);
 }
 
@@ -134,11 +134,11 @@ static GtkWidget *_terminal_build_menu (GtkWidget *pWidget, gchar *cReceivedData
 void on_terminal_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, gint x, gint y, GtkSelectionData *selection_data, guint info, guint t, gpointer data)
 {
 	static gchar *cReceivedData = NULL;  // il faut pouvoir le passer aux callbacks. Le probleme c'est qu'il disparait a la fin de cette fonction, donc il faut le dupliquer. Comme on n'est pas sur que l'une des callbacks sera effectivement appelee, ce ne peut pas etre elles qui le desalloueront. Donc on le fait ici, d'ou la variable statique. On ne peut recevoir qu'un drop a la fois, donc pas de collision possible.
-	cd_message ("%s ()\n", __func__);
+	cd_message ("%s ()", __func__);
 
 	g_free (cReceivedData);
 	cReceivedData = NULL;
-	const gchar *cText = gtk_selection_data_get_text (selection_data);;
+	gchar *cText = (gchar *)gtk_selection_data_get_text (selection_data);
 	g_return_if_fail (cText != NULL);
 
 	int length = strlen (cReceivedData);
@@ -146,15 +146,16 @@ void on_terminal_drag_data_received (GtkWidget *pWidget, GdkDragContext *dc, gin
 		cReceivedData[--length] = '\0';  // on vire le retour chariot final.
 	if (cReceivedData[length-1] == '\r')
 		cReceivedData[--length] = '\0';  // on vire ce ... c'est quoi ce truc ??!
-	cd_message ("cReceivedData : %s\n", cReceivedData);
+	cd_message ("cReceivedData : %s", cReceivedData);
 
 	if (strncmp (cText, "file://", 7) == 0)  // on gere le cas des URI.
 	{
 		GError *erreur = NULL;
 		cReceivedData = g_filename_from_uri (cText, NULL, &erreur);
+		g_free (cText);
 		if (erreur != NULL)
 		{
-			cd_message ("Terminal : %s\n", erreur->message);
+			cd_message ("Terminal : %s", erreur->message);
 			g_error_free (erreur);
 			return ;
 		}
